<?php

namespace None\FXC\Http\Controllers;

use App\Http\Controllers\ActionController as BaseController;
use Exception;
use None\FXC\Actions\TestAction;
use None\FXC\Http\Requests\TestActionRequest;
use None\FXC\Http\Resources\TestResource;
use None\FXC\Models\Test;

/**
 * Admin web controller class.
 */
class TestActionController extends BaseController
{

    /**
     * Action controller function for test.
     *
     * @param Model $model
     * @param action next action for the model.
     *
     * @return Response
     */
    public function __invoke(TestActionRequest $request, Test $test, $action)
    {
        try {
            $test = TestAction::run($request, $test, $action);

            $data = new TestResource($test);
            return $this->response->message(trans("messages.success.{$action}", ['Module' => trans('f_x_c::test.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('f_x_c/test/' . $test->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('f_x_c/test/' . $test->getRouteKey()))
                ->redirect();
        }
    }

    public function notify(){
        
    }
}
