<?php

namespace None\FXC\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Database\RequestScope;
use None\FXC\Forms\Test as TestForm;
use None\FXC\Http\Requests\TestResourceRequest;
use None\FXC\Http\Resources\TestResource;
use None\FXC\Http\Resources\TestsCollection;
use None\FXC\Models\Test;
use None\FXC\Scopes\TestResourceScope;


/**
 * Resource controller class for test.
 */
class TestResourceController extends BaseController
{

    /**
     * Initialize test resource controller.
     *
     *
     * @return null
     */
    public function __construct()
    {
        parent::__construct();
        $this->form = TestForm::grouped(false)
                        ->setAttributes()
                        ->toArray();
        $this->modules = $this->modules(config('none.f_x_c.modules'), 'f_x_c', guard_url('f_x_c'));
    }

    /**
     * Display a list of test.
     *
     * @return Response
     */
    public function index(TestResourceRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $page = Test::pushScope(new RequestScope())
            ->pushScope(new TestResourceScope())
            ->paginate($pageLimit);

        $data = new TestsCollection($page);

        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('f_x_c::test.names'))
            ->view('f_x_c::test.index')
            ->data(compact('data', 'modules', 'form'))
            ->output();

    }

    /**
     * Display test.
     *
     * @param Request $request
     * @param Model   $test
     *
     * @return Response
     */
    public function show(TestResourceRequest $request, Test $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new TestResource($model);
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('f_x_c::test.name'))
            ->data(compact('data', 'form', 'modules'))
            ->view('f_x_c::test.show')
            ->output();
    }

    /**
     * Show the form for creating a new test.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TestResourceRequest $request, Test $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new TestResource($model);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('f_x_c::test.name'))
            ->view('f_x_c::test.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Create new test.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TestResourceRequest $request, Test $model)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $model = $model->create($attributes);
            $data = new TestResource($model);
            return $this->response->message(trans('messages.success.created', ['Module' => trans('f_x_c::test.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('f_x_c/test/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/f_x_c/test'))
                ->redirect();
        }

    }

    /**
     * Show test for editing.
     *
     * @param Request $request
     * @param Model   $test
     *
     * @return Response
     */
    public function edit(TestResourceRequest $request, Test $model)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = new TestResource($model);
        // return view('f_x_c::test.edit', compact('data', 'form', 'modules'));

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('f_x_c::test.name'))
            ->view('f_x_c::test.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();

    }

    /**
     * Update the test.
     *
     * @param Request $request
     * @param Model   $test
     *
     * @return Response
     */
    public function update(TestResourceRequest $request, Test $model)
    {
        try {
            $attributes = $request->all();
            $model->update($attributes);
            $data = new TestResource($model);

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('f_x_c::test.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('f_x_c/test/' . $model->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('f_x_c/test/' .  $model->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the test.
     *
     * @param Model   $test
     *
     * @return Response
     */
    public function destroy(TestResourceRequest $request, Test $model)
    {
        try {
            $model->delete();
            $data = new TestResource($model);

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('f_x_c::test.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('f_x_c/test/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('f_x_c/test/' .  $model->getRouteKey()))
                ->redirect();
        }

    }
}
